@@ -16,15 +16,15 @@ class Preset:
     location: str
     target_id: str
 
-    def upload(self, api: API, manual: bool):
+    def upload(self, api: API, manual: bool) -> str:
         if not os.path.exists(self.location):
             raise PresetError(f"No such file or directory: {self.location}")
 
         if os.path.isdir(self.location):
-            api.upload_backup_folder(self.target_id, self.location, manual)
+            return api.upload_backup_folder(self.target_id, self.location, manual)
         else:
             with open(self.location, "rb") as file:
-                api.upload_backup(self.target_id, file, os.path.basename(self.location), manual)
+                return api.upload_backup(self.target_id, file, os.path.basename(self.location), manual)
 
     @staticmethod
     def from_dict(d: dict) -> "Preset":
